==> qt-creator-opensource-src-4.0.1.zip: qt-creator-opensource-src-4.0.1/src/plugins/autotest/autotestconstants.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef AUTOTESTCONSTANTS_H
#define AUTOTESTCONSTANTS_H

#include <QtGlobal>

namespace Autotest {
namespace Constants {

const char ACTION_SCAN_ID[]             = "AutoTest.ScanAction";
const char ACTION_RUN_ALL_ID[]          = "AutoTest.RunAll";
const char ACTION_RUN_SELECTED_ID[]     = "AutoTest.RunSelected";
const char MENU_ID[]                    = "AutoTest.Menu";
const char AUTOTEST_ID[]                = "AutoTest.ATP";
const char AUTOTEST_CONTEXT[]           = "Auto Tests";
const char TASK_INDEX[]                 = "AutoTest.Task.Index";
const char TASK_PARSE[]                 = "AutoTest.Task.Parse";
const char UNNAMED_QUICKTESTS[]         = QT_TR_NOOP("<unnamed>");
const char AUTOTEST_SETTINGS_CATEGORY[] = "ZY.Tests";

} // namespace Constants

namespace Internal {

enum TestType
{
    TestTypeQt,
    TestTypeGTest
};

} // namespace Internal
} // namespace Autotest

#endif // AUTOTESTCONSTANTS_H

==> qt-creator-opensource-src-4.1.0.zip: qt-creator-opensource-src-4.1.0/src/plugins/autotest/autotestconstants.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QtGlobal>

namespace Autotest {
namespace Constants {

const char ACTION_SCAN_ID[]             = "AutoTest.ScanAction";
const char ACTION_RUN_ALL_ID[]          = "AutoTest.RunAll";
const char ACTION_RUN_SELECTED_ID[]     = "AutoTest.RunSelected";
const char MENU_ID[]                    = "AutoTest.Menu";
const char AUTOTEST_ID[]                = "AutoTest.ATP";
const char AUTOTEST_CONTEXT[]           = "Auto Tests";
const char TASK_INDEX[]                 = "AutoTest.Task.Index";
const char TASK_PARSE[]                 = "AutoTest.Task.Parse";
const char AUTOTEST_SETTINGS_CATEGORY[] = "ZY.Tests";
const char FRAMEWORK_PREFIX[]           = "AutoTest.Framework.";

} // namespace Constants
} // namespace Autotest
